@@ -90,7 +90,7 @@ public:
     };
 
     explicit OpenDBJob(const QString& dbName, DbType type = TM::Local, bool reconnect = false, const ConnectionParams& connParams = ConnectionParams());
-    ~OpenDBJob();
+    ~OpenDBJob() override = default;
 
     int priority() const
     {
@@ -309,7 +309,7 @@ class ScanJob: public QRunnable
 {
 public:
     explicit ScanJob(const QString& filePath, const QString& dbName);
-    ~ScanJob();
+    ~ScanJob() override = default;
 
     int priority() const
     {
@@ -362,7 +362,7 @@ public:
         : QObject(), QRunnable()
         , m_view(view)
     {}
-    ~BatchSelectFinishedJob() override {}
+    ~BatchSelectFinishedJob() override = default;
 
     int priority() const
     {
